# Generated by roxygen2: do not edit by hand

S3method("[",clust_fns_list)
S3method("[",data_list)
S3method("[",dist_fns_list)
S3method("[",ext_solutions_df)
S3method("[",settings_df)
S3method("[",sim_mats_list)
S3method("[",snf_config)
S3method("[",solutions_df)
S3method("[",weights_matrix)
S3method("[<-",ari_matrix)
S3method("[<-",clust_fns_list)
S3method("[<-",data_list)
S3method("[<-",dist_fns_list)
S3method("[<-",ext_solutions_df)
S3method("[<-",settings_df)
S3method("[<-",sim_mats_list)
S3method("[<-",snf_config)
S3method("[<-",solutions_df)
S3method("[<-",t_ext_solutions_df)
S3method("[<-",t_solutions_df)
S3method("[<-",weights_matrix)
S3method(as.data.frame,data_list)
S3method(as.data.frame,ext_solutions_df)
S3method(as.data.frame,settings_df)
S3method(as.data.frame,snf_config)
S3method(as.data.frame,solutions_df)
S3method(as.data.frame,t_ext_solutions_df)
S3method(as.data.frame,t_solutions_df)
S3method(as.data.frame,weights_matrix)
S3method(as.list,clust_fns_list)
S3method(as.list,data_list)
S3method(as.list,dist_fns_list)
S3method(as.list,sim_mats_list)
S3method(as.list,snf_config)
S3method(as.matrix,ari_matrix)
S3method(as.matrix,weights_matrix)
S3method(as_ari_matrix,matrix)
S3method(as_data_list,list)
S3method(as_settings_df,data.frame)
S3method(as_sim_mats_list,list)
S3method(as_snf_config,ext_solutions_df)
S3method(as_snf_config,solutions_df)
S3method(as_weights_matrix,matrix)
S3method(c,ari_matrix)
S3method(c,clust_fns_list)
S3method(c,data_list)
S3method(c,dist_fns_list)
S3method(c,ext_solutions_df)
S3method(c,settings_df)
S3method(c,sim_mats_list)
S3method(c,snf_config)
S3method(c,solutions_df)
S3method(c,t_ext_solutions_df)
S3method(c,t_solutions_df)
S3method(features,data_list)
S3method(features,ext_solutions_df)
S3method(features,solutions_df)
S3method(merge,ari_matrix)
S3method(merge,clust_fns_list)
S3method(merge,data_list)
S3method(merge,dist_fns_list)
S3method(merge,ext_solutions_df)
S3method(merge,settings_df)
S3method(merge,sim_mats_list)
S3method(merge,snf_config)
S3method(merge,solutions_df)
S3method(merge,t_ext_solutions_df)
S3method(merge,t_solutions_df)
S3method(merge,weights_matrix)
S3method(n_features,data_list)
S3method(n_observations,data_list)
S3method(plot,ari_matrix)
S3method(plot,clust_fns_list)
S3method(plot,data_list)
S3method(plot,dist_fns_list)
S3method(plot,ext_solutions_df)
S3method(plot,settings_df)
S3method(plot,sim_mats_list)
S3method(plot,snf_config)
S3method(plot,solutions_df)
S3method(plot,t_ext_solutions_df)
S3method(plot,t_solutions_df)
S3method(plot,weights_matrix)
S3method(print,ari_matrix)
S3method(print,clust_fns_list)
S3method(print,data_list)
S3method(print,dist_fns_list)
S3method(print,ext_solutions_df)
S3method(print,settings_df)
S3method(print,sim_mats_list)
S3method(print,snf_config)
S3method(print,solutions_df)
S3method(print,t_ext_solutions_df)
S3method(print,t_solutions_df)
S3method(print,weights_matrix)
S3method(rbind,ari_matrix)
S3method(rbind,clust_fns_list)
S3method(rbind,data_list)
S3method(rbind,dist_fns_list)
S3method(rbind,ext_solutions_df)
S3method(rbind,sim_mats_list)
S3method(rbind,snf_config)
S3method(rbind,solutions_df)
S3method(rbind,t_solutions_df)
S3method(rbind,weights_matrix)
S3method(sim_mats_list,default)
S3method(sim_mats_list,ext_solutions_df)
S3method(sim_mats_list,solutions_df)
S3method(str,ari_matrix)
S3method(str,clust_fns_list)
S3method(str,data_list)
S3method(str,dist_fns_list)
S3method(str,ext_solutions_df)
S3method(str,settings_df)
S3method(str,sim_mats_list)
S3method(str,snf_config)
S3method(str,solutions_df)
S3method(str,t_ext_solutions_df)
S3method(str,t_solutions_df)
S3method(str,weights_matrix)
S3method(summary,ari_matrix)
S3method(summary,clust_fns_list)
S3method(summary,data_list)
S3method(summary,dist_fns_list)
S3method(summary,ext_solutions_df)
S3method(summary,settings_df)
S3method(summary,sim_mats_list)
S3method(summary,snf_config)
S3method(summary,solutions_df)
S3method(summary,t_ext_solutions_df)
S3method(summary,t_solutions_df)
S3method(summary,weights_matrix)
S3method(summary_features,ext_solutions_df)
S3method(t,ari_matrix)
S3method(t,clust_fns_list)
S3method(t,data_list)
S3method(t,dist_fns_list)
S3method(t,ext_solutions_df)
S3method(t,settings_df)
S3method(t,sim_mats_list)
S3method(t,snf_config)
S3method(t,solutions_df)
S3method(t,t_ext_solutions_df)
S3method(t,t_solutions_df)
S3method(t,weights_matrix)
S3method(uids,data_list)
S3method(uids,default)
S3method(uids,ext_solutions_df)
S3method(uids,sim_mats_list)
S3method(uids,solutions_df)
S3method(uids,t_ext_solutions_df)
S3method(uids,t_solutions_df)
export(add_settings_df_rows)
export(adjusted_rand_index_heatmap)
export(alluvial_cluster_plot)
export(as_ari_matrix)
export(as_data_list)
export(as_settings_df)
export(as_sim_mats_list)
export(as_snf_config)
export(as_weights_matrix)
export(assemble_data)
export(assoc_pval_heatmap)
export(auto_plot)
export(bar_plot)
export(batch_snf)
export(batch_snf_subsamples)
export(calc_aris)
export(calc_assoc_pval_matrix)
export(calc_nmis)
export(calculate_coclustering)
export(calculate_db_indices)
export(calculate_dunn_indices)
export(calculate_silhouettes)
export(cell_significance_fn)
export(check_dataless_annotations)
export(check_hm_dependencies)
export(check_similarity_matrices)
export(clust_fns_list)
export(cocluster_density)
export(cocluster_heatmap)
export(collapse_dl)
export(colour_scale)
export(config_heatmap)
export(data_list)
export(dist_fns_list)
export(dl_variable_summary)
export(dlapply)
export(dplyr_row_slice.ext_solutions_df)
export(dplyr_row_slice.solutions_df)
export(esm_manhattan_plot)
export(estimate_nclust_given_graph)
export(euclidean_distance)
export(extend_solutions)
export(features)
export(generate_distance_metrics_list)
export(generate_settings_matrix)
export(get_cluster_df)
export(get_cluster_solutions)
export(get_clusters)
export(get_complete_uids)
export(get_dl_uids)
export(get_heatmap_order)
export(get_matrix_order)
export(get_pvals)
export(get_representative_solutions)
export(gower_distance)
export(hamming_distance)
export(is_data_list)
export(jitter_plot)
export(label_meta_clusters)
export(label_propagate)
export(linear_adjust)
export(linear_model_pval)
export(mc_manhattan_plot)
export(merge_df_list)
export(meta_cluster_heatmap)
export(n_features)
export(n_observations)
export(new_solutions_df)
export(ord_reg_pval)
export(pl)
export(pval_heatmap)
export(random_removal)
export(rename_dl)
export(resample)
export(save_heatmap)
export(settings_df)
export(sew_euclidean_distance)
export(shiny_annotator)
export(sim_mats_list)
export(similarity_matrix_heatmap)
export(siw_euclidean_distance)
export(sn_euclidean_distance)
export(snf_config)
export(spectral_eigen)
export(spectral_eigen_classic)
export(spectral_eight)
export(spectral_five)
export(spectral_four)
export(spectral_nine)
export(spectral_rot)
export(spectral_rot_classic)
export(spectral_seven)
export(spectral_six)
export(spectral_ten)
export(spectral_three)
export(spectral_two)
export(split_parser)
export(subsample_dl)
export(subsample_pairwise_aris)
export(summarize_clust_fns_list)
export(summarize_dfl)
export(summarize_dl)
export(summary_features)
export(train_test_assign)
export(uids)
export(validate_solutions_df)
export(var_manhattan_plot)
export(weights_matrix)
importFrom(data.table,":=")
importFrom(data.table,as.data.table)
importFrom(data.table,setkey)
importFrom(data.table,setnames)
importFrom(progressr,with_progress)
