## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----echo = FALSE-------------------------------------------------------------
options(crayon.enabled = FALSE, cli.num_colors = 0)

## ----eval = FALSE-------------------------------------------------------------
# install.packages("devtools") # if you don't have it already
# 
# # By default, this will install the latest version of the package
# devtools::install_github("BRANCHlab/metasnf")
# 
# # To ensure you are always installing a specific version of the package,
# #  you can manually specify a tagged release or a commit:
# devtools::install_github("BRANCHlab/metasnf@v0.2.0")

